@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.010000;
 
-our $VERSION = '1.113_10';
+our $VERSION = '1.114_01';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -68,7 +68,6 @@ sub __set_defaults {
     $self->{layout}           //= 1;
     #$self->{lf}              //= undef;
     #$self->{ll}              //= undef;
-    #$self->{limit}           //= undef;
     #$self->{max_height}      //= undef;
     #$self->{max_width}       //= undef;
     $self->{mouse}            //= 0;
@@ -96,7 +95,6 @@ sub __validate_options {
         layout          => '[ 0 1 2 3 ]',
         lf              => 'ARRAY',
         ll              => '[ 1-9 ][ 0-9 ]*',
-        #limit           => '[ 1-9 ][ 0-9 ]*',
         max_height      => '[ 1-9 ][ 0-9 ]*',
         max_width       => '[ 1-9 ][ 0-9 ]*',
         mouse           => '[ 0 1 2 3 4 ]',
@@ -207,11 +205,8 @@ sub choose {
     local $\ = undef;
     local $, = undef;
     local $| = 1;
-    $self->{wantarray}  = wantarray;
+    $self->{wantarray} = wantarray;
     $self->__set_defaults();
-    if ( $self->{limit} && @$orig_list_ref > $self->{limit} ) {
-        $self->{list_to_long} = 1;
-    }
     $self->{orig_list} = $orig_list_ref;
     $self->__copy_orig_list();
     $self->__length_longest();
@@ -599,58 +594,29 @@ sub __beep {
 sub __copy_orig_list {
     my ( $self ) = @_;
     if ( $self->{ll} ) {
-        if ( $self->{list_to_long} ) {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                $copy;
-            } @{$self->{orig_list}}[ 0 .. $self->{limit} - 1 ] ];
-        }
-        else {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                $copy;
-            } @{$self->{orig_list}} ];
-        }
+        $self->{list} = [ map {
+            my $copy = $_;
+            if ( ! $copy ) {
+                $copy = $self->{undef} if ! defined $copy;
+                $copy = $self->{empty} if $copy eq '';
+            }
+            $copy;
+        } @{$self->{orig_list}} ];
     }
     else {
-        if ( $self->{list_to_long} ) {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                if ( ref $copy ) {
-                    $copy = sprintf "%s(0x%x)", ref $copy, $copy;
-                }
-                $copy =~ s/\p{Space}/ /g;  # replace, but don't squash sequences of spaces
-                $copy =~ s/\p{C}//g;
-                $copy;
-            } @{$self->{orig_list}}[ 0 .. $self->{limit} - 1 ] ];
-        }
-        else {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                if ( ref $copy ) {
-                    $copy = sprintf "%s(0x%x)", ref $copy, $copy;
-                }
-                $copy =~ s/\p{Space}/ /g;
-                $copy =~ s/\p{C}//g;
-                $copy;
-            } @{$self->{orig_list}} ];
-        }
+        $self->{list} = [ map {
+            my $copy = $_;
+            if ( ! $copy ) {
+                $copy = $self->{undef} if ! defined $copy;
+                $copy = $self->{empty} if $copy eq '';
+            }
+            if ( ref $copy ) {
+                $copy = sprintf "%s(0x%x)", ref $copy, $copy;
+            }
+            $copy =~ s/\p{Space}/ /g;  # replace, but don't squash sequences of spaces
+            $copy =~ s/\p{C}//g;
+            $copy;
+        } @{$self->{orig_list}} ];
     }
 }
 
@@ -1114,7 +1080,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.113_10
+Version 1.114_01
 
 =cut
 
@@ -1499,15 +1465,6 @@ See C<INITIAL_TAB> and C<SUBSEQUENT_TAB> in L<Text::LineFold>.
 
 (default: undefined)
 
-=head2 limit
-
-Sets the maximal allowed length of the array. (default: undefined)
-
-If the array referred by the first argument has more than I<limit> elements choose uses only the first I<limit> array
-elements.
-
-Allowed values: 1 or greater
-
 =head2 ll
 
 If all elements have the same length and this length is known before calling C<choose> the length can be passed with
