@@ -11,16 +11,13 @@ use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Choose;
 
-my $a_ref = Data_Test_Choose::test_options();
-my $b_ref = Data_Test_Choose::test_list();
 
 my $type = shift;
-my $list = $b_ref->{$type};
-
-
+my $a_ref = Data_Test_Choose::return_test_data( $type );
 
 for my $ref ( @$a_ref ) {
-    my $opt = $ref->{options};
+    my $opt  = $ref->{options};
+    my $list = $ref->{list};
     my @choice = choose(
         $list,
         $opt
